@@ -237,8 +237,8 @@ class ResponseParser:
             always be present.
 
         """
-        LOG.debug('Response headers: %s', response['headers'])
-        LOG.debug('Response body:\n%s', response['body'])
+        LOG.debug('Response headers: %r', response['headers'])
+        LOG.debug('Response body:\n%r', response['body'])
         if response['status_code'] >= 301:
             if self._is_generic_error_response(response):
                 parsed = self._do_generic_error_parse(response)
@@ -706,6 +706,7 @@ class BaseJSONParser(ResponseParser):
         code = None
         if len(query_error_components) == 2 and query_error_components[0]:
             code = query_error_components[0]
+            error['Error']['Type'] = query_error_components[1]
         if code is None:
             code = body.get('__type', response_code and str(response_code))
         if code is not None:
