@@ -13,6 +13,7 @@
 
 import base64
 import copy
+import io
 import json
 import os
 
@@ -22,7 +23,7 @@ import botocore
 import botocore.session
 from botocore import handlers
 from botocore.awsrequest import AWSRequest
-from botocore.compat import OrderedDict, quote, six
+from botocore.compat import OrderedDict, quote
 from botocore.config import Config
 from botocore.credentials import Credentials
 from botocore.docs.bcdoc.restdoc import DocumentStructure
@@ -584,7 +585,9 @@ class TestHandlers(BaseSessionTest):
 
     def test_run_instances_userdata(self):
         user_data = 'This is a test'
-        b64_user_data = base64.b64encode(six.b(user_data)).decode('utf-8')
+        b64_user_data = base64.b64encode(user_data.encode('latin-1')).decode(
+            'utf-8'
+        )
         params = dict(
             ImageId='img-12345678', MinCount=1, MaxCount=5, UserData=user_data
         )
@@ -705,7 +708,7 @@ class TestHandlers(BaseSessionTest):
     def test_glacier_checksums_added(self):
         request_dict = {
             'headers': {},
-            'body': six.BytesIO(b'hello world'),
+            'body': io.BytesIO(b'hello world'),
         }
         handlers.add_glacier_checksums(request_dict)
         self.assertIn('x-amz-content-sha256', request_dict['headers'])
@@ -726,7 +729,7 @@ class TestHandlers(BaseSessionTest):
             'headers': {
                 'x-amz-sha256-tree-hash': 'pre-exists',
             },
-            'body': six.BytesIO(b'hello world'),
+            'body': io.BytesIO(b'hello world'),
         }
         handlers.add_glacier_checksums(request_dict)
         self.assertEqual(
@@ -738,7 +741,7 @@ class TestHandlers(BaseSessionTest):
             'headers': {
                 'x-amz-content-sha256': 'pre-exists',
             },
-            'body': six.BytesIO(b'hello world'),
+            'body': io.BytesIO(b'hello world'),
         }
         handlers.add_glacier_checksums(request_dict)
         self.assertEqual(
@@ -1104,7 +1107,7 @@ class TestConvertStringBodyToFileLikeObject(BaseSessionTest):
         self.assert_converts_to_file_like_object_with_bytes(body, body_bytes)
 
     def test_file(self):
-        body = six.StringIO()
+        body = io.StringIO()
         params = {'Body': body}
         handlers.convert_body_to_file_like_object(params)
         self.assertEqual(params['Body'], body)
@@ -1357,7 +1360,7 @@ class TestAddMD5(BaseMD5Test):
         self.assertTrue('Content-MD5' in request_dict['headers'])
 
     def test_add_md5_with_file_like_body(self):
-        request_dict = {'body': six.BytesIO(b'foobar'), 'headers': {}}
+        request_dict = {'body': io.BytesIO(b'foobar'), 'headers': {}}
         self.md5_digest.return_value = b'8X\xf6"0\xac<\x91_0\x0cfC\x12\xc6?'
         conditionally_calculate_md5(request_dict)
         self.assertEqual(
@@ -1390,7 +1393,7 @@ class TestAddMD5(BaseMD5Test):
 
     def test_skip_md5_when_flexible_checksum_context(self):
         request_dict = {
-            'body': six.BytesIO(b'foobar'),
+            'body': io.BytesIO(b'foobar'),
             'headers': {},
             'context': {
                 'checksum': {
@@ -1407,7 +1410,7 @@ class TestAddMD5(BaseMD5Test):
 
     def test_skip_md5_when_flexible_checksum_explicit_header(self):
         request_dict = {
-            'body': six.BytesIO(b'foobar'),
+            'body': io.BytesIO(b'foobar'),
             'headers': {'x-amz-checksum-crc32': 'foo'},
         }
         conditionally_calculate_md5(request_dict)
